@@ -1,13 +1,15 @@
 #include "kimeraapp.h"
 #include "inputmethod.h"
+#include "config.h"
+#include <qregexp.h>
 
-InputMethod* KimeraApp::inpmethod = 0;
+static InputMethod* inpmethod = 0;
 
 KimeraApp::KimeraApp(int &argc, char **argv) : QApplication(argc, argv)
 {
+  qAddPostRoutine( cleanup_ptr );   // delete object
 }
 
-
 //
 // Returns a pointer to the application global inputmethod.
 //
@@ -17,7 +19,6 @@ KimeraApp::inputmethod()
   if ( !inpmethod ) {
     inpmethod = new InputMethod();
     Q_CHECK_PTR( inpmethod );
-    qAddPostRoutine( cleanup_ptr );   // delete later
   }
   
   return inpmethod;
@@ -27,7 +28,8 @@ KimeraApp::inputmethod()
 void
 KimeraApp::cleanup_ptr()
 {
-  delete inpmethod;
+  if (inpmethod)
+    delete inpmethod;
   inpmethod = 0;
 }
 
@@ -35,13 +37,13 @@ KimeraApp::cleanup_ptr()
 bool 
 KimeraApp::x11EventFilter(XEvent* event)
 {
-  if ( !inpmethod ) return FALSE;
+  if ( !inpmethod )
+    return FALSE;
 
   if (event->type == ClientMessage) {
     ClientMessageEvent e(event);
     sendEvent(inpmethod, &e);
     return FALSE;
-
   } else if (event->type >= SelectionClear && event->type <= SelectionNotify) {
     SelectionEvent e(event);
     sendEvent(inpmethod, &e);
