@@ -5,6 +5,8 @@
 #include <qevent.h>
 
 class InputMethod;
+class KanjiEngine;
+
 
 class KimeraApp : public QApplication {
 public:  
@@ -22,18 +24,21 @@ public:
 protected:
   bool x11EventFilter(XEvent *);
   static void cleanup_ptr();
-
-private:
-  static InputMethod* inpmethod;
 };
 
 
+//
+// Selection event class
+//
 class SelectionEvent : public QCustomEvent {
 public:
   SelectionEvent(void* data) : QCustomEvent((Type)KimeraApp::Selection, data) {}
 };
 
 
+//
+// ClientMessage event class
+//
 class ClientMessageEvent : public QCustomEvent {
 public:
   ClientMessageEvent(void* data) : QCustomEvent((Type)KimeraApp::XIMClientMessage, data) {}
